@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2015-01-02'; # DATE
-our $VERSION = '0.43'; # VERSION
+our $DATE = '2015-02-18'; # DATE
+our $VERSION = '0.44'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,7 +16,6 @@ use Locale::TextDomain::UTF8 'Perinci-Sub-Gen-AccessTable';
 use Perinci::Object::Metadata;
 use Perinci::Sub::Gen;
 use Perinci::Sub::Util qw(err);
-use Scalar::Util qw(reftype);
 #use String::Trim::More qw(trim_blank_lines);
 
 require Exporter;
@@ -26,8 +25,8 @@ our @EXPORT_OK = qw(gen_read_table_func);
 our %SPEC;
 
 sub __parse_schema {
-    require Data::Sah;
-    Data::Sah::normalize_schema($_[0]);
+    require Data::Sah::Normalize;
+    Data::Sah::Normalize::normalize_schema($_[0]);
 }
 
 sub __is_aoa {
@@ -702,7 +701,7 @@ sub _gen_func {
         }
         if (__is_aoa($table_data) || __is_aoh($table_data)) {
             $data = $table_data;
-        } elsif (reftype($table_data) eq 'CODE') {
+        } elsif (ref($table_data) eq 'CODE') {
             my $res;
             return err(500, "BUG: Table data function died: $@")
                 unless eval { $res = $table_data->($query) };
@@ -1323,7 +1322,7 @@ sub gen_read_table_func {
     my $table_data = $args{table_data}
         or return [400, "Please specify table_data"];
     __is_aoa($table_data) or __is_aoh($table_data) or
-        reftype($table_data) eq 'CODE'
+        ref($table_data) eq 'CODE'
             or return [400, "Invalid table_data: must be AoA/AoH/function"];
     my $table_spec = $args{table_spec}
         or return [400, "Please specify table_spec"];
@@ -1414,7 +1413,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.43 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-01-02.
+This document describes version 0.44 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-02-18.
 
 =head1 SYNOPSIS
 
@@ -1844,6 +1843,7 @@ element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value: A hash containing generated function, metadata (hash)
+
 =head1 CAVEATS
 
 It is often not a good idea to expose your database schema directly as API.
@@ -1877,7 +1877,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Gen-AccessTable>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Gen-AccessTable>.
 
 =head1 BUGS
 
